%define with_ext2resize  0
%define ext2resize_ver   1.1.19

%define libname          libe2fs

Name:          e2fsprogs
Version:       1.47.1
Release:       1mamba
Summary:       Utilities for managing the ext2/3/4 filesystem
Group:         System/Tools
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://e2fsprogs.sourceforge.net/
Source0:       http://downloads.sourceforge.net/e2fsprogs/e2fsprogs-%{version}.tar.gz
Source1:       http://downloads.sourceforge.net/ext2resize/ext2resize-%{ext2resize_ver}.tar.bz2
Source2:       e2fsck-conf
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libblkid-devel
BuildRequires: libfuse3-devel
BuildRequires: libuuid-devel
## AUTOBUILDREQ-END
BuildRequires: gettext-devel
BuildRequires: texinfo
Requires(pre): /sbin/ldconfig
Requires(pre): /usr/sbin/groupadd
Requires(pre): /usr/sbin/useradd
Requires(post):%{__install_info}

%description
The e2fsprogs package contains a number of utilities for creating, checking, modifying, and correcting any inconsistencies in second (ext2) extended filesystems.
E2fsprogs contains e2fsck (used to repair filesystem inconsistencies after an unclean shutdown), mke2fs (used to initialize a partition to contain an empty ext2 filesystem), debugfs (used to examine the internal structure of a filesystem, to manually repair a corrupted filesystem, or to create test cases for e2fsck), tune2fs (used to modify filesystem parameters), and most of the other core ext2fs filesystem utilities.
It also supports the ext3 and ext4 filesystems with journaling support.

You should install the e2fsprogs package if you need to manage the performance of an ext2 filesystem.

%package -n %{libname}
Summary:       The development file for application which use e2fsprogs
Group:         System/Libraries

%description -n %{libname}
The e2fsprogs package contains a number of utilities for creating, checking, modifying and correcting any inconsistencies in second extended (ext2) filesystems.
You should install %{libname} to use tools who use ext2fs features.

%package -n %{libname}-devel
Summary:       The development file for application which use e2fsprogs
Group:         Development/Libraries
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}

%description -n %{libname}-devel
This package contains the libraries and header files needed to develop second extended (ext2) filesystem-specific programs.
You should install e2fsprogs-devel if you want to develop ext2 filesystem-specific programs.

%debug_package

%prep
%setup -q -a1

%build
%if "%{_host}" != "%{_build}"
sed -i "s|-lblkid|-lblkid -luuid|" configure
%endif
%configure \
   --enable-elf-shlibs \
   --enable-nls \
   --enable-quota \
   --disable-e2initrd-helper \
   --disable-libblkid \
   --disable-libuuid \
   --disable-uuidd \
   --disable-fsck \
   CC=%{_target_platform}-gcc \
   LD=%{_target_platform}-ld

%if "%{_host}" == "%{_build}"
%make
%else
%make LDFLAGS="-ldl -lpthread"
%endif

%if %with_ext2resize
pushd ext2resize-%{ext2resize_ver}
%configure
%make
popd
%endif

make -C po update-po

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%makeinstall install-libs

install -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/e2fsck.conf

%if %with_ext2resize
pushd ext2resize-%{ext2resize_ver}
%makeinstall
mv -f AUTHORS AUTHORS.ext2resize
mv -f COPYING COPYING.ext2resize
mv -f NEWS NEWS.ext2resize
mv -f README README.ext2resize
mv -f doc/HOWTO HOWTO.ext2resize
popd
%endif

# Permissions workaround
chmod 644 %{buildroot}%{_libdir}/*.a

%find_lang %{name}

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%post -n %{libname}-devel
%install_info libext2fs.info

%preun -n %{libname}-devel
%uninstall_info libext2fs.info
exit 0

%files -f %{name}.lang
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/e2fsck.conf
%config(noreplace) %{_sysconfdir}/mke2fs.conf
%{_sysconfdir}/cron.d/e2scrub_all
%{_sysconfdir}/e2scrub.conf
%{_bindir}/chattr
%{_bindir}/fuse2fs
%{_bindir}/lsattr
%{_sbindir}/*
%{_unitdir}/e2scrub@.service
%{_unitdir}/e2scrub_all.service
%{_unitdir}/e2scrub_all.timer
%{_unitdir}/e2scrub_fail@.service
%{_unitdir}/e2scrub_reap.service
%{_udevrulesdir}/96-e2scrub.rules
%{_udevrulesdir}/64-ext4.rules
%{_mandir}/man1/chattr.*
%{_mandir}/man1/fuse2fs.1*
%{_mandir}/man1/lsattr.*
%{_mandir}/man5/ext2.5*
%{_mandir}/man5/ext3.5*
%{_mandir}/man5/ext4.5*
%{_mandir}/man5/e2fsck.conf.*
%{_mandir}/man5/mke2fs.conf.*
%{_mandir}/man8/*

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libcom_err.so.*
%{_libdir}/libe2p.so.*
%{_libdir}/libext2fs.so.*
%{_libdir}/libss.so.*
%dir %{_libexecdir}/e2fsprogs
%{_libexecdir}/e2fsprogs/*
%doc NOTICE

%files -n %{libname}-devel
%defattr(-,root,root)
%{_bindir}/compile_et
%{_bindir}/mk_cmds
%{_datadir}/et/*
%{_datadir}/ss/*
%{_includedir}/com_err.h
%{_includedir}/e2p/
%{_includedir}/et/
%{_includedir}/ext2fs/
#%{_includedir}/quota/mkquota.h
%{_includedir}/ss/
%{_libdir}/libcom_err.so
%{_libdir}/*.a
%{_libdir}/*.so
%{_libdir}/pkgconfig/com_err.pc
%{_libdir}/pkgconfig/e2p.pc
%{_libdir}/pkgconfig/ext2fs.pc
#%{_libdir}/pkgconfig/quota.pc
%{_libdir}/pkgconfig/ss.pc
%{_mandir}/man1/mk_cmds.*
%{_mandir}/man1/compile_et.*
%{_mandir}/man3/*
%{_infodir}/libext2fs.info*
#%doc README RELEASE-NOTES
%if %with_ext2resize
%doc ext2resize-%{ext2resize_ver}/*.ext2resize
%endif

%changelog
* Sun May 26 2024 Automatic Build System <autodist@openmamba.org> 1.47.1-1mamba
- automatic version update by autodist

* Tue Feb 07 2023 Automatic Build System <autodist@mambasoft.it> 1.47.0-1mamba
- automatic version update by autodist

* Sat Feb 04 2023 Automatic Build System <autodist@mambasoft.it> 1.46.6-1mamba
- automatic version update by autodist

* Tue Jun 21 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 1.46.5-2mamba
- fix permissions of /etc/e2fsck.conf

* Fri Dec 31 2021 Automatic Build System <autodist@mambasoft.it> 1.46.5-1mamba
- automatic version update by autodist

* Mon Aug 23 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 1.46.4-1mamba
- update to 1.46.4

* Sat May 01 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 1.46.2-2mamba
- rebuilt in /usr

* Mon Mar 01 2021 Automatic Build System <autodist@mambasoft.it> 1.46.2-1mamba
- automatic version update by autodist

* Wed Feb 10 2021 Automatic Build System <autodist@mambasoft.it> 1.46.1-1mamba
- automatic version update by autodist

* Sat Jan 30 2021 Automatic Build System <autodist@mambasoft.it> 1.46.0-1mamba
- automatic version update by autodist

* Fri Jan 29 2021 Automatic Build System <autodist@mambasoft.it> 1.45.7-1mamba
- automatic version update by autodist

* Sun Mar 22 2020 Automatic Build System <autodist@mambasoft.it> 1.45.6-1mamba
- automatic version update by autodist

* Wed Jan 08 2020 Automatic Build System <autodist@mambasoft.it> 1.45.5-1mamba
- automatic version update by autodist

* Tue Sep 24 2019 Automatic Build System <autodist@mambasoft.it> 1.45.4-1mamba
- automatic version update by autodist

* Thu Jul 18 2019 Automatic Build System <autodist@mambasoft.it> 1.45.3-1mamba
- automatic version update by autodist

* Tue May 28 2019 Automatic Build System <autodist@mambasoft.it> 1.45.2-1mamba
- automatic version update by autodist

* Mon May 13 2019 Automatic Build System <autodist@mambasoft.it> 1.45.1-1mamba
- automatic version update by autodist

* Fri Mar 08 2019 Automatic Build System <autodist@mambasoft.it> 1.45.0-1mamba
- automatic version update by autodist

* Wed Mar 06 2019 Automatic Build System <autodist@mambasoft.it> 1.44.6-1mamba
- automatic version update by autodist

* Sun Dec 16 2018 Automatic Build System <autodist@mambasoft.it> 1.44.5-1mamba
- automatic version update by autodist

* Sun Aug 19 2018 Automatic Build System <autodist@mambasoft.it> 1.44.4-1mamba
- automatic version update by autodist

* Sun Jul 15 2018 Automatic Build System <autodist@mambasoft.it> 1.44.3-1mamba
- automatic version update by autodist

* Thu May 17 2018 Automatic Build System <autodist@mambasoft.it> 1.44.2-1mamba
- automatic version update by autodist

* Sun Mar 25 2018 Automatic Build System <autodist@mambasoft.it> 1.44.1-1mamba
- automatic version update by autodist

* Thu Mar 08 2018 Automatic Build System <autodist@mambasoft.it> 1.44.0-1mamba
- automatic version update by autodist

* Fri Feb 09 2018 Automatic Build System <autodist@mambasoft.it> 1.43.9-1mamba
- automatic version update by autodist

* Tue Jan 02 2018 Automatic Build System <autodist@mambasoft.it> 1.43.8-1mamba
- automatic version update by autodist

* Tue Oct 24 2017 Automatic Build System <autodist@mambasoft.it> 1.43.7-1mamba
- automatic version update by autodist

* Fri Sep 01 2017 Automatic Build System <autodist@mambasoft.it> 1.43.6-1mamba
- automatic version update by autodist

* Mon Aug 07 2017 Automatic Build System <autodist@mambasoft.it> 1.43.5-1mamba
- automatic version update by autodist

* Sun Feb 05 2017 Automatic Build System <autodist@mambasoft.it> 1.43.4-1mamba
- automatic version update by autodist

* Mon Sep 05 2016 Automatic Build System <autodist@mambasoft.it> 1.43.3-1mamba
- automatic version update by autodist

* Fri Sep 02 2016 Automatic Build System <autodist@mambasoft.it> 1.43.2-1mamba
- automatic version update by autodist

* Thu Jun 09 2016 Automatic Build System <autodist@mambasoft.it> 1.43.1-1mamba
- automatic version update by autodist

* Thu May 26 2016 Automatic Build System <autodist@mambasoft.it> 1.43-1mamba
- automatic version update by autodist

* Mon May 18 2015 Automatic Build System <autodist@mambasoft.it> 1.42.13-1mamba
- automatic version update by autodist

* Sat Aug 30 2014 Automatic Build System <autodist@mambasoft.it> 1.42.12-1mamba
- automatic version update by autodist

* Fri Jul 11 2014 Automatic Build System <autodist@mambasoft.it> 1.42.11-1mamba
- automatic version update by autodist

* Wed Jun 04 2014 Automatic Build System <autodist@mambasoft.it> 1.42.10-1mamba
- automatic update by autodist

* Sun Dec 29 2013 Automatic Build System <autodist@mambasoft.it> 1.42.9-1mamba
- automatic version update by autodist

* Fri Jun 21 2013 Automatic Build System <autodist@mambasoft.it> 1.42.8-1mamba
- automatic version update by autodist

* Tue Jan 22 2013 Automatic Build System <autodist@mambasoft.it> 1.42.7-1mamba
- automatic version update by autodist

* Sun Sep 23 2012 Automatic Build System <autodist@mambasoft.it> 1.42.6-1mamba
- automatic version update by autodist

* Tue Jul 31 2012 Automatic Build System <autodist@mambasoft.it> 1.42.5-1mamba
- automatic version update by autodist

* Wed Jun 13 2012 Automatic Build System <autodist@mambasoft.it> 1.42.4-1mamba
- automatic version update by autodist

* Tue May 15 2012 Automatic Build System <autodist@mambasoft.it> 1.42.3-1mamba
- automatic version update by autodist

* Wed Mar 28 2012 Automatic Build System <autodist@mambasoft.it> 1.42.2-1mamba
- automatic version update by autodist

* Sun Feb 19 2012 Automatic Build System <autodist@mambasoft.it> 1.42.1-1mamba
- automatic version update by autodist

* Fri Jan 27 2012 Automatic Build System <autodist@mambasoft.it> 1.42-1mamba
- automatic version update by autodist

* Thu Dec 23 2010 Automatic Build System <autodist@mambasoft.it> 1.41.14-1mamba
- automatic update to 1.41.14 by autodist

* Wed Dec 15 2010 Automatic Build System <autodist@mambasoft.it> 1.41.13-1mamba
- automatic update to 1.41.13 by autodist

* Tue May 18 2010 Automatic Build System <autodist@mambasoft.it> 1.41.12-1mamba
- automatic update to 1.41.12 by autodist

* Mon Mar 15 2010 Automatic Build System <autodist@mambasoft.it> 1.41.11-1mamba
- automatic update to 1.41.11 by autodist

* Fri Mar 12 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 1.41.10-2mamba
- e2fsck.conf: remove mount time based checks to prevent boot failures when system clock goes back (http://forums.debian.net/viewtopic.php?f=10&t=45797)

* Sun Feb 14 2010 Automatic Build System <autodist@mambasoft.it> 1.41.10-1mamba
- automatic update to 1.41.10 by autodist

* Tue Sep 08 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.41.9-2mamba
- install /etc/e2fsck.conf with buggy_init_scripts=1 to prevent boot problems due to superblock last write date in the future caused by kinit mount

* Sat Aug 29 2009 Automatic Build System <autodist@mambasoft.it> 1.41.9-1mamba
- automatic update to 1.41.9 by autodist

* Sun Jul 26 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.41.8-2mamba
- rebuild with external libuuid (provided by util-linux-ng 2.16)

* Tue Jul 14 2009 Automatic Build System <autodist@mambasoft.it> 1.41.8-1mamba
- automatic update by autodist

* Wed Jul 01 2009 Automatic Build System <autodist@mambasoft.it> 1.41.7-1mamba
- automatic update to 1.41.7 by autodist

* Sun May 31 2009 Automatic Build System <autodist@mambasoft.it> 1.41.6-1mamba
- automatic update to 1.41.6 by autodist

* Mon May 18 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.41.5-2mamba
- disable build of libblkid and use the newer provided by util-linux-ng

* Fri Apr 24 2009 Automatic Build System <autodist@mambasoft.it> 1.41.5-1mamba
- automatic update to 1.41.5 by autodist

* Thu Jan 29 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.41.4-1mamba
- automatic update to 1.41.4 by autodist

* Tue Oct 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.41.3-1mamba
- automatic update to 1.41.3 by autodist

* Fri Oct 03 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.41.2-1mamba
- automatic update to 1.41.2 by autodist

* Sat Sep 06 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.41.1-1mamba
- automatic update to 1.41.1 by autodist

* Sat Jul 05 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.40.11-1mamba
- update to 1.40.11

* Tue Jun 03 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.40.10-1mamba
- update to 1.40.10

* Wed Apr 30 2008 Aleph0 <aleph0@openmamba.org> 1.40.9-1mamba
- update to 1.40.9

* Tue Mar 18 2008 Aleph0 <aleph0@openmamba.org> 1.40.8-1mamba
- update to 1.40.8

* Fri Feb 29 2008 Aleph0 <aleph0@openmamba.org> 1.40.7-1mamba
- update to 1.40.7

* Tue Feb 12 2008 Aleph0 <aleph0@openmamba.org> 1.40.6-1mamba
- update to 1.40.6
- new subpackage uuidd

* Mon Dec 17 2007 Aleph0 <aleph0@openmamba.org> 1.40.3-1mamba
- update to 1.40.3 (fixes CVE-2007-5497)

* Mon Jul 16 2007 Aleph0 <aleph0@openmamba.org> 1.40.2-1mamba
- update to 1.40.2

* Mon Jul 09 2007 Aleph0 <aleph0@openmamba.org> 1.40.1-1mamba
- update to 1.40.1

* Mon Jul 02 2007 Aleph0 <aleph0@openmamba.org> 1.40-1mamba
- update to 1.40
- man3 pages moved to the devel package

* Tue Jul 05 2005 Davide Madrisan <davide.madrisan@qilinux.it> 1.38-1qilnx
- update to version 1.38 by autospec
- added scripts to install/uninstall info files
- own directories with header files

* Wed Mar 23 2005 Davide Madrisan <davide.madrisan@qilinux.it> 1.37-1qilnx
- update to version 1.37 by autospec
- added mising %%postun script for `libe2fs'
- moved `libext2fs.info.gz' to devel package
- conditionally build the ext2resize software (disabled for now)

* Wed Jan 05 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.35-2qilnx
- added missing libcom_err.so file

* Mon Mar 01 2004 Davide Madrisan <davide.madrisan@qilinux.it> 1.35-1qilnx
- new version build

* Fri Nov 14 2003 Silvan Calarco <silvan.calarco@mambasoft.it> 1.34-1qilnx
- new version build

* Mon Apr 07 2003 Luca Tinelli <luca.tinelli@qinet.it> 1.32-1qilnx
- first build
